KeyEvent class

Represents a keyboard event from terminal input.

Constructors

KeyEvent({required KeyCode code, int? charCode, Set<KeyModifier> modifiers = const {}})
const

Properties

charCode int?
final
code KeyCode
final
hashCode int
The hash code for this object.
no setterinherited
isAlt bool
no setter
isCtrl bool
no setter
isMeta bool
no setter
isShift bool
no setter
modifiers Set<KeyModifier>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited