diffIter method
Lazy iterator over the diff between this buffer and other.
Implementation
BufferDiff diffIter(Buffer other) => BufferDiff(content, other.content, area);
Lazy iterator over the diff between this buffer and other.
BufferDiff diffIter(Buffer other) => BufferDiff(content, other.content, area);