BufferDiff class

Lazily iterates over cells that differ between two buffers.

Handles multi-width characters (CJK, emoji), CellDiffOption.skip, and CellDiffOption.forcedWidth.

Constructors

BufferDiff(List<Cell> _prev, List<Cell> _next, Rect _area)

Properties

current CellUpdate
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

moveNext() bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited