Cell.withChar constructor
Cell.withChar(
- int char
Create a cell with the specified char code point.
Implementation
factory Cell.withChar(int char) => Cell()..setChar(char);
Create a cell with the specified char code point.
factory Cell.withChar(int char) => Cell()..setChar(char);