CellDiffOption enum
Controls how a Cell behaves during diffing.
Values
- none → const CellDiffOption
-
Normal: compared and emitted only if changed.
- skip → const CellDiffOption
-
Always skipped during diffing.
- alwaysUpdate → const CellDiffOption
-
Always emitted even if unchanged.
- forcedWidth → const CellDiffOption
-
Occupies forcedWidth cells, skipping trailing cells.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
CellDiffOption> - A constant List of the values in this enum, in order of their declaration.