CellUpdate class

A single cell change to send to the backend during drawing.

Constructors

CellUpdate(int x, int y, Cell cell)
const

Properties

cell Cell
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
x int
final
y int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited