core/core library

Classes

Buffer
A grid of Cells representing the desired terminal content.
BufferDiff
Lazily iterates over cells that differ between two buffers.
Cell
A single character cell in the terminal buffer.
CellUpdate
A single cell change to send to the backend during drawing.
IndexedColor
A color from the 256-color indexed palette.
Line
A single line of text composed of styled Spans.
Modifier
Bit-flag text modifiers for terminal styling.
Position
A position in the terminal coordinate system.
Rect
A rectangular area in the terminal coordinate system.
RgbColor
A 24-bit RGB color for use with Color.rgb.
Size
Dimensions (width and height) in character cells.
Span
A contiguous piece of text with a single Style.
Style
Incremental text style with foreground/background colors and modifiers.
Text
Multi-line styled text composed of Lines.

Enums

CellDiffOption
Controls how a Cell behaves during diffing.
Color
Terminal color selection.

Extensions

BufferIndex on Buffer
RectIterators on Rect
Iterators over rows, columns, and positions within a Rect.

Functions

charWidth(int rune) int
Returns the terminal display width of a Unicode code point.
charWidthOf(String s) int
Terminal display width of the first grapheme in s.