Line class

A single line of text composed of styled Spans.

Constructors

Line(List<Span> spans, {Style style = Style.empty})
const
Line.raw(String content)
factory
Line.styled(String content, Style style)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spans List<Span>
final
style Style
final
width int
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pushSpan(Span span) → void
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override