Modifier class

Bit-flag text modifiers for terminal styling.

Modifiers can be combined with the | operator:

Modifier.bold | Modifier.italic

Properties

bits int
Internal bitmask.
final
hashCode int
The hash code for this object.
no setteroverride
isEmpty bool
Whether no flags are set.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

contains(Modifier other) bool
Whether this set contains all flags in other.
difference(Modifier other) Modifier
Returns flags in this set that are not in other.
intersection(Modifier other) Modifier
Alias for &.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override
union(Modifier other) Modifier
Alias for |.

Operators

operator &(Modifier other) Modifier
Intersect two modifier sets.
operator ==(Object other) bool
The equality operator.
override
operator |(Modifier other) Modifier
Combine two modifier sets.
operator ~() Modifier
Invert all bits.

Constants

all → const Modifier
All modifier flags combined.
bold → const Modifier
Bold / bright text. ANSI \x1b[1m.
crossedOut → const Modifier
Crossed-out / strikethrough text. ANSI \x1b[9m.
dim → const Modifier
Dim / faint text. ANSI \x1b[2m.
hidden → const Modifier
Hidden text. ANSI \x1b[8m.
italic → const Modifier
Italic text. ANSI \x1b[3m.
none → const Modifier
No modifiers.
Rapid blink. ANSI \x1b[6m.
reversed → const Modifier
Reversed / inverted colors. ANSI \x1b[7m.
Slow blink. ANSI \x1b[5m.
underlined → const Modifier
Underlined text. ANSI \x1b[4m.