toString method

  1. @override
String toString()
override

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  if (isEmpty) return 'NONE';
  final parts = <String>[];
  if (contains(bold)) parts.add('BOLD');
  if (contains(dim)) parts.add('DIM');
  if (contains(italic)) parts.add('ITALIC');
  if (contains(underlined)) parts.add('UNDERLINED');
  if (contains(slowBlink)) parts.add('SLOW_BLINK');
  if (contains(rapidBlink)) parts.add('RAPID_BLINK');
  if (contains(reversed)) parts.add('REVERSED');
  if (contains(hidden)) parts.add('HIDDEN');
  if (contains(crossedOut)) parts.add('CROSSED_OUT');
  return parts.join(' | ');
}