Size class

Dimensions (width and height) in character cells.

Constructors

Size(int width, int height)
const

Properties

area int
Total area in character cells.
no setter
hashCode int
The hash code for this object.
no setteroverride
height int
Number of rows.
final
isEmpty bool
Whether either dimension is zero.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width int
Number of columns.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

zero → const Size
Zero size (0, 0).