Span class

A contiguous piece of text with a single Style.

Constructors

Span(String content, {Style style = Style.empty})
const
Span.raw(String content)
factory
Span.styled(String content, Style style)
factory

Properties

content String
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style Style
final
width int
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override