toString method

  1. @override
String toString()
override

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  final parts = <String>[];
  if (fg != null) parts.add('fg: $fg');
  if (bg != null) parts.add('bg: $bg');
  if (fgRgb != null) parts.add('fgRgb: $fgRgb');
  if (bgRgb != null) parts.add('bgRgb: $bgRgb');
  if (fgIndexed != null) parts.add('fgIndexed: $fgIndexed');
  if (bgIndexed != null) parts.add('bgIndexed: $bgIndexed');
  if (!addModifier.isEmpty) parts.add('+$addModifier');
  if (!subModifier.isEmpty) parts.add('-$subModifier');
  return 'Style(${parts.join(', ')})';
}