Text class

Multi-line styled text composed of Lines.

Constructors

Text(List<Line> lines, {Style style = Style.empty})
const
Text.raw(String content)
factory
Text.styled(String content, Style style)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
height int
no setter
lines List<Line>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style Style
final
width int
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override