Focus class

A widget that makes its child focusable via keyboard navigation.

Inheritance

Constructors

Focus({Key? key, Widget? child, FocusNode? node, bool canFocus = true, KeyHandler? onKey})
const

Properties

canFocus bool
final
child Widget?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
key Key?
finalinherited
node FocusNode?
final
onKey KeyHandler?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() Element
inherited
createRenderObject() RenderObject
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited