FocusNode class

Represents a focusable node in the widget tree.

Tracks whether this node has focus, can receive focus, and provides a key event handler.

Constructors

FocusNode({bool canFocus = true, KeyHandler? onKey})

Properties

canFocus bool
getter/setter pair
hasFocus bool
no setter
hashCode int
The hash code for this object.
no setterinherited
onKey KeyHandler?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addListener(VoidCallback cb) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeListener(VoidCallback cb) → void
requestFocus() → void
toString() String
A string representation of this object.
inherited
unfocus() → void

Operators

operator ==(Object other) bool
The equality operator.
inherited