BuildContext class

The location of a Widget in the element tree.

Used to access inherited widgets, ancestor widgets, and theme data.

Constructors

BuildContext(Element? _element)

Properties

element Element?
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dependOnInheritedWidgetOfExactType<T extends InheritedWidget>() → T?
findAncestorWidgetOfExactType<T extends Widget>() → T?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
updateDependencies() → void

Operators

operator ==(Object other) bool
The equality operator.
inherited