InheritedWidget class abstract
A widget that propagates data down the widget tree.
Children can access the data via BuildContext.dependOnInheritedWidgetOfExactType.
- Inheritance
-
- Object
- Widget
- StatelessWidget
- InheritedWidget
Constructors
- InheritedWidget({Key? key})
-
const
Properties
Methods
-
build(
BuildContext context) → Widget -
override
-
createElement(
) → Element -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited