RenderMultiChild class abstract
A render object with a list of children.
- Inheritance
-
- Object
- RenderObject
- RenderMultiChild
- Implementers
Constructors
Properties
-
children
→ List<
RenderObject> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → int
-
no setterinherited
- parent ↔ RenderObject?
-
getter/setter pairinherited
- rect → Rect
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- width → int
-
no setterinherited
- x → int
-
no setterinherited
- y → int
-
no setterinherited
Methods
-
layout(
BoxConstraints constraints) → void -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
paint(
Buffer buffer, Rect area) → void -
override
-
paintSelf(
Buffer buffer, Rect area) → void -
performLayout(
BoxConstraints constraints) → void -
inherited
-
setChildren(
List< RenderObject> newChildren) → void -
setOffset(
int x, int y) → void -
inherited
-
setSize(
int w, int h) → void -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited