RenderObject class abstract

The base class for all render objects.

RenderObjects perform layout via performLayout and rendering via paint. They form a tree that mirrors the widget structure.

Implementers

Constructors

RenderObject()

Properties

hashCode int
The hash code for this object.
no setterinherited
height int
no setter
parent RenderObject?
getter/setter pair
rect Rect
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width int
no setter
x int
no setter
y int
no setter

Methods

layout(BoxConstraints constraints) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(Buffer buffer, Rect area) → void
performLayout(BoxConstraints constraints) → void
setOffset(int x, int y) → void
setSize(int w, int h) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited