StatefulWidget class abstract
A widget that has mutable state.
State is managed in a separate State object created by createState.
Constructors
- StatefulWidget({Key? key})
-
const
Properties
Methods
-
createElement(
) → Element -
override
-
createState(
) → State< StatefulWidget> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited