StatelessElement class
Constructors
- StatelessElement(Widget widget)
Properties
- context → BuildContext
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- parent ↔ Element?
-
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- widget ↔ Widget
-
getter/setter pairinherited
Methods
-
build(
) → Widget -
override
-
mount(
Element? parent, dynamic slot) → void -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
unmount(
) → void -
inherited
-
update(
Widget newWidget) → void -
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited