StatelessWidget class abstract
A widget that does not require mutable state.
Describes part of the UI by building a subtree of widgets in build.
- Inheritance
- Implementers
Constructors
- StatelessWidget({Key? key})
-
const
Properties
Methods
-
build(
BuildContext context) → Widget -
createElement(
) → Element -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited