framework/theme library

Classes

Theme
A widget that defines the theme for its subtree.
ThemeData
Holds the color and style values for a visual theme.
ThemeProvider
Static provider for the current theme data.