ThemeData class

Holds the color and style values for a visual theme.

Use ThemeData.dark or ThemeData.light for presets, or create a custom theme by setting individual fields.

Constructors

ThemeData({Color? primaryColor, Color? secondaryColor, Color? backgroundColor, Color? surfaceColor, Color? textColor, Color? disabledColor, Color? errorColor, Style? textStyle, Style? headingStyle, Style? borderStyle, Style? focusedBorderStyle})
const

Properties

backgroundColor Color?
final
borderStyle Style?
final
disabledColor Color?
final
errorColor Color?
final
focusedBorderStyle Style?
final
hashCode int
The hash code for this object.
no setterinherited
headingStyle Style?
final
primaryColor Color?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondaryColor Color?
final
surfaceColor Color?
final
textColor Color?
final
textStyle Style?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

dark → const ThemeData
light → const ThemeData