CompletedFrame class
Snapshot of the terminal state after a completed render pass.
Constructors
- CompletedFrame({required Buffer buffer, required Rect area, required int count})
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited