Frame class

A single render frame providing access to the current buffer.

Constructors

Frame(Rect _viewportArea, Buffer _buffer, int _count)

Properties

area Rect
no setter
buffer Buffer
no setter
count int
no setter
cursorPosition Position?
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setCursorPosition(Position pos) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited