Viewport class

Defines where and how the UI is rendered on the terminal.

Constructors

Viewport.fixed(Rect rect)
const
Viewport.fullscreen()
const
Viewport.inline(int height)
const

Properties

fixedRect Rect?
final
hashCode int
The hash code for this object.
no setterinherited
inlineHeight int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type ViewportType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited