widgets/align library

Classes

Align
A widget that positions its child within the available space using a AlignmentEnum anchor point.
RenderAlign
Render object that positions its child using alignment.

Enums

Alignment
Anchor points for positioning a child within its parent.