Align class

A widget that positions its child within the available space using a AlignmentEnum anchor point.

Inheritance

Constructors

Align({Key? key, required Alignment alignment, Widget? child})
const

Properties

alignment Alignment
final
child Widget?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
key Key?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() Element
inherited
createRenderObject() RenderObject
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited