Border class

Draws a box-drawing border around its child.

Uses characters ┌┐└┘─│. Supports focusedStyle when a focus ancestor is active.

Inheritance

Constructors

Border({Key? key, Widget? child, Style? style, Style? focusedStyle})
const

Properties

child Widget?
finalinherited
focusedStyle Style?
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style Style?
final

Methods

createElement() Element
inherited
createRenderObject() RenderObject
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited