Button class

A focusable button that responds to Enter or Space. Shows visual focus feedback via focusedStyle.

Inheritance

Constructors

Button({Key? key, required String label, VoidCallback? onPressed, Style? style, Style? focusedStyle, Style? activeStyle})
const

Properties

activeStyle Style?
final
focusedStyle Style?
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
finalinherited
label String
final
onPressed VoidCallback?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style Style?
final

Methods

build(BuildContext context) Widget
override
createElement() Element
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited