RenderContainer class

Inheritance

Constructors

RenderContainer(Style style, EdgeInsets padding)

Properties

child RenderObject?
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
height int
no setterinherited
padding EdgeInsets
getter/setter pair
parent RenderObject?
getter/setter pairinherited
rect Rect
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style Style
getter/setter pair
width int
no setterinherited
x int
no setterinherited
y int
no setterinherited

Methods

layout(BoxConstraints constraints) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(Buffer buffer, Rect area) → void
inherited
paintSelf(Buffer buffer, Rect area) → void
override
performLayout(BoxConstraints constraints) → void
override
setChild(RenderObject? newChild) → void
inherited
setOffset(int x, int y) → void
inherited
setSize(int w, int h) → void
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited