Expanded class
A widget that expands to fill the available space in a Row or Column.
The flex parameter determines how remaining space is distributed among sibling Expanded widgets.
- Inheritance
-
- Object
- Widget
- RenderWidget
- SingleChildRenderWidget
- Expanded
Properties
Methods
-
createElement(
) → Element -
inherited
-
createRenderObject(
) → RenderObject -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited