EdgeInsets class

Defines insets (padding) for each side of a rectangle.

Constructors

EdgeInsets.all(int value)
const
EdgeInsets.only({int left = 0, int top = 0, int right = 0, int bottom = 0})
const
EdgeInsets.symmetric({int horizontal = 0, int vertical = 0})
const

Properties

bottom int
final
hashCode int
The hash code for this object.
no setterinherited
horizontal int
no setter
left int
final
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
top int
final
vertical int
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited