SizedBox class

A widget with a fixed sWidth and/or sHeight.

If a dimension is 0, the parent's constraint is used.

Inheritance

Constructors

SizedBox({Key? key, int? sWidth, int? sHeight, Widget? child})
const

Properties

child Widget?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
key Key?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sHeight int?
final
sWidth int?
final

Methods

createElement() Element
inherited
createRenderObject() RenderObject
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited