TextWidget class
A widget that displays a string of styled text.
- Inheritance
-
- Object
- Widget
- RenderWidget
- SingleChildRenderWidget
- TextWidget
Constructors
- TextWidget(String data, {Key? key, Style? style})
-
const
Properties
Methods
-
createElement(
) → Element -
inherited
-
createRenderObject(
) → RenderObject -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited