backend/backend library
Classes
- AnsiBackend
- ANSI terminal backend implementation.
- CellUpdate
- A single cell change to send to the backend during drawing.
- KeyEvent
- Represents a keyboard event from terminal input.
- TerminalBackend
- Abstract interface for terminal rendering backends.
- TestBackend
- In-memory terminal backend for testing.
Enums
- ClearType
- Defines which region of the terminal display to clear.
- KeyCode
- Identifies a physical key press.
- KeyModifier
- Modifier keys (Shift, Alt, Ctrl, Meta).