Focus class
A widget that makes its child focusable via keyboard navigation.
- Inheritance
Constructors
Properties
Methods
-
createElement(
) → Element -
inherited
-
createRenderObject(
) → RenderObject -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited