framework/framework_core library
Classes
- AppScheduler
- Frame scheduling with rate limiting (~30fps).
- BoxConstraints
- Constraints for layout, similar to Flutter's BoxConstraints.
- BuildContext
- The location of a Widget in the element tree.
- Element
- InheritedElement
- InheritedWidget
- A widget that propagates data down the widget tree.
- Key
- A key used to identify and preserve widget state across rebuilds.
- MultiChildRenderWidget
- A render widget with multiple children.
- RenderLeaf
- A render object with no children (leaf node).
- RenderMultiChild
- A render object with a list of children.
- RenderObject
- The base class for all render objects.
- RenderPipelineResult
- RenderSingleChild
- A render object with exactly one child.
- RenderWidget
- A widget that creates a RenderObject for rendering.
- SingleChildRenderWidget
- A render widget with a single child.
-
State<
T extends StatefulWidget> - The mutable state for a StatefulWidget.
- StatefulElement
- StatefulWidget
- A widget that has mutable state.
- StatelessElement
- StatelessWidget
- A widget that does not require mutable state.
- Widget
- The base class for all widgets.
Functions
-
renderPipeline(
Widget root, Size terminalSize) → RenderPipelineResult -
runTerminalApp(
Widget root, {ThemeData? theme}) → void
Typedefs
- VoidCallback = void Function()