BuildContext class
The location of a Widget in the element tree.
Used to access inherited widgets, ancestor widgets, and theme data.
Constructors
- BuildContext(Element? _element)
Properties
Methods
-
dependOnInheritedWidgetOfExactType<
T extends InheritedWidget> () → T? -
findAncestorWidgetOfExactType<
T extends Widget> () → T? -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
updateDependencies(
) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited