RenderObject class abstract
The base class for all render objects.
RenderObjects perform layout via performLayout and rendering via paint. They form a tree that mirrors the widget structure.
- Implementers
Constructors
Properties
Methods
-
layout(
BoxConstraints constraints) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
paint(
Buffer buffer, Rect area) → void -
performLayout(
BoxConstraints constraints) → void -
setOffset(
int x, int y) → void -
setSize(
int w, int h) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited