Theme class
A widget that defines the theme for its subtree.
Use Theme.of to access the current theme data from any descendant.
- Inheritance
-
- Object
- Widget
- StatelessWidget
- Theme
Properties
Methods
-
build(
BuildContext context) → Widget -
override
-
createElement(
) → Element -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
of(
BuildContext context) → ThemeData