Terminal class
Manages double-buffered terminal rendering.
Maintains two Buffers (current and previous), computes diffs between frames, and sends only changed cells to the TerminalBackend.
Constructors
- Terminal(TerminalBackend backend)
-
factory
- Terminal.withOptions(TerminalBackend backend, TerminalOptions options)
-
factory
Properties
- backend → TerminalBackend
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clear(
) → void -
dispose(
) → void -
draw(
void callback(Frame)) → CompletedFrame -
getFrame(
) → Frame -
hideCursor(
) → void -
keyEvents(
) → Stream< KeyEvent> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setCursorPosition(
Position pos) → void -
showCursor(
) → void -
toString(
) → String -
A string representation of this object.
inherited
-
tryDraw(
void callback(Frame)?) → CompletedFrame?
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited