Padding class
A widget that insets its child by a given padding.
- Inheritance
Constructors
- Padding({Key? key, required EdgeInsets padding, Widget? child})
-
const
Properties
- child → Widget?
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
finalinherited
- padding → EdgeInsets
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createElement(
) → Element -
inherited
-
createRenderObject(
) → RenderObject -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited