ScrollView class
A scrollable container for content larger than the viewport.
- Inheritance
-
- Object
- Widget
- RenderWidget
- SingleChildRenderWidget
- ScrollView
Constructors
- ScrollView({Key? key, Widget? child, AxisDirection direction = AxisDirection.vertical})
-
const
Properties
- child → Widget?
-
finalinherited
- direction → AxisDirection
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createElement(
) → Element -
inherited
-
createRenderObject(
) → RenderObject -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited