TextField class
An editable text input field with cursor and keyboard support. Supports character input, backspace, delete, arrow keys, home/end.
- Inheritance
-
- Object
- Widget
- StatefulWidget
- TextField
Constructors
Properties
- focusedStyle → Style?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- initialValue → String?
-
final
- key → Key?
-
finalinherited
- onSubmitted → bool Function(String)?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- style → Style?
-
final
- width → int
-
final
Methods
-
createElement(
) → Element -
inherited
-
createState(
) → State< StatefulWidget> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited